@@ -54,9 +54,7 @@ results <- batch(
     positive = TRUE,
     initial_window = init_win,
     lead_time = lead,
-    trace = FALSE,
-    basis_knot_distance = 0.01,
-    basis_deg = 1
+    trace = FALSE
 )
 
 # ts.plot(results$weights[, , 1], col = rainbow(ncol(results$weights)))
@@ -65,4 +63,4 @@ results <- batch(
 expect_gt(results$weights[change_at + 5, , 1], 0.2)
 
 expect_lt(results$weights[change_at + lead + 5, , 1], 0.2)
-# %%
\ No newline at end of file
+# %%
