@@ -16,15 +16,16 @@ y <- rnorm(n = T)
 # Expert predictions
 experts <- array(dim = c(T, P, N))
 for (t in 1:T) {
-    experts[t, , 1] <- qnorm(prob_grid, mean = -5, sd = 2)
-    experts[t, , 2] <- qnorm(prob_grid, mean = 5, sd = 2)
+  experts[t, , 1] <- qnorm(prob_grid, mean = -5, sd = 2)
+  experts[t, , 2] <- qnorm(prob_grid, mean = 5, sd = 2)
 }
 
 model <- online(
-    y = matrix(y),
-    experts = experts,
-    tau = prob_grid,
-    trace = FALSE
+  y = matrix(y),
+  experts = experts,
+  tau = prob_grid,
+  trace = FALSE,
+  get_timings = TRUE
 )
 
 # Return Type
@@ -41,4 +42,4 @@ expect_true(all(!is.na(model$predictions)))
 expect_true(all(!is.na(model$past_perf_wrt_params)))
 expect_true(all(!is.na(model$opt_index)))
 expect_true(all(!is.na(model$forecaster_loss)))
-expect_true(all(!is.na(model$experts_loss)))
\ No newline at end of file
+expect_true(all(!is.na(model$experts_loss)))
